==> imsdk-plus-6.8.3373-sources.jar: com/tencent/imsdk/message/MessageOfflinePushInfo.java <==
package com.tencent.imsdk.message;

import java.io.Serializable;

public class MessageOfflinePushInfo implements Serializable {
    public static final int OFFLINE_PUSH_FLAG_DEFAULT = 0;
    public static final int OFFLINE_PUSH_FLAG_NO_PUSH = 1;

    public static final int OFFLINE_APNS_BADGE_MODE_DEFAULT = 0;
    public static final int OFFLINE_APNS_BADGE_MODE_IGNORE  = 1;

    private String title;
    private String description;
    private byte[] extension;
    private String soundFilePath;
    private int pushFlag;
    private APNSOfflinePushInfo apnsConfig = new APNSOfflinePushInfo();
    private AndroidOfflinePushInfo androidConfig = new AndroidOfflinePushInfo();

    public class APNSOfflinePushInfo implements Serializable{
        private String title;
        private String description;
        private String soundFilePath;
        private int badgeMode;
        private int iOSPushType = 0;

        public void setSoundFilePath(String soundFilePath) {
            this.soundFilePath = soundFilePath;
        }

        public void setBadgeMode(int badgeMode) {
            this.badgeMode = badgeMode;
        }

        public void setIOSPushType(int iOSPushType) {
            this.iOSPushType = iOSPushType;
        }
    }

    public class AndroidOfflinePushInfo implements Serializable{
        private String title;
        private String description;
        private String soundFilePath;
        private int notifyMode;
        private String oppoChannelID;
        private int vivoClassification = 1;

        public void setOppoChannelID(String oppoChannelID) {
            this.oppoChannelID = oppoChannelID;
        }

        public void setVivoClassification(int vivoClassification) {
            this.vivoClassification = vivoClassification;
        }

        public void setSoundFilePath(String soundFilePath) {
            this.soundFilePath = soundFilePath;
        }
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public byte[] getExtension() {
        return extension;
    }

    public void setExtension(byte[] extension) {
        this.extension = extension;
    }

    public String getSoundFilePath() {
        return soundFilePath;
    }

    public void setSoundFilePath(String soundFilePath) {
        this.soundFilePath = soundFilePath;
    }

    public int getPushFlag() {
        return pushFlag;
    }

    public void setPushFlag(int pushFlag) {
        this.pushFlag = pushFlag;
    }

    public APNSOfflinePushInfo getApnsConfig() {
        return apnsConfig;
    }

    public void setApnsConfig(APNSOfflinePushInfo apnsConfig) {
        this.apnsConfig = apnsConfig;
    }

    public AndroidOfflinePushInfo getAndroidConfig() {
        return androidConfig;
    }

    public void setAndroidConfig(AndroidOfflinePushInfo androidConfig) {
        this.androidConfig = androidConfig;
    }
}

==> imsdk-plus-7.9.5680-sources.jar: com/tencent/imsdk/message/MessageOfflinePushInfo.java <==
package com.tencent.imsdk.message;

import java.io.Serializable;

public class MessageOfflinePushInfo implements Serializable {
    public static final int OFFLINE_PUSH_FLAG_DEFAULT = 0;
    public static final int OFFLINE_PUSH_FLAG_NO_PUSH = 1;

    public static final int OFFLINE_APNS_BADGE_MODE_DEFAULT = 0;
    public static final int OFFLINE_APNS_BADGE_MODE_IGNORE = 1;

    private String title;
    private String description;
    private byte[] extension;
    private String soundFilePath;
    private int pushFlag;
    private APNSOfflinePushInfo apnsConfig = new APNSOfflinePushInfo();
    private AndroidOfflinePushInfo androidConfig = new AndroidOfflinePushInfo();

    public class APNSOfflinePushInfo implements Serializable {
        private String title;
        private String description;
        private String soundFilePath;
        private int badgeMode;
        private int iOSPushType = 0;

        public void setSoundFilePath(String soundFilePath) {
            this.soundFilePath = soundFilePath;
        }

        public void setBadgeMode(int badgeMode) {
            this.badgeMode = badgeMode;
        }

        public void setIOSPushType(int iOSPushType) {
            this.iOSPushType = iOSPushType;
        }
    }

    public class AndroidOfflinePushInfo implements Serializable {
        private String title;
        private String description;
        private String soundFilePath;
        private int notifyMode;
        private String oppoChannelID;
        private String fcmChannelID;
        private String xiaomiChannelID;
        private int vivoClassification = 1;
        private String vivoCategory;
        private String huaweiCategory;

        public void setOppoChannelID(String oppoChannelID) {
            this.oppoChannelID = oppoChannelID;
        }

        public void setFCMChannelID(String fcmChannelID) {
            this.fcmChannelID = fcmChannelID;
        }

        public void setXiaoMiChannelID(String xiaomiChannelID) {
            this.xiaomiChannelID = xiaomiChannelID;
        }

        public void setVivoClassification(int vivoClassification) {
            this.vivoClassification = vivoClassification;
        }

        public void setVivoCategory(String vivoCategory) {
            this.vivoCategory = vivoCategory;
        }

        public void setSoundFilePath(String soundFilePath) {
            this.soundFilePath = soundFilePath;
        }

        public void setHuaWeiCategory(String huaweiCategory) {
            this.huaweiCategory = huaweiCategory;
        }
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public byte[] getExtension() {
        return extension;
    }

    public void setExtension(byte[] extension) {
        this.extension = extension;
    }

    public String getSoundFilePath() {
        return soundFilePath;
    }

    public void setSoundFilePath(String soundFilePath) {
        this.soundFilePath = soundFilePath;
    }

    public int getPushFlag() {
        return pushFlag;
    }

    public void setPushFlag(int pushFlag) {
        this.pushFlag = pushFlag;
    }

    public APNSOfflinePushInfo getApnsConfig() {
        return apnsConfig;
    }

    public void setApnsConfig(APNSOfflinePushInfo apnsConfig) {
        this.apnsConfig = apnsConfig;
    }

    public AndroidOfflinePushInfo getAndroidConfig() {
        return androidConfig;
    }

    public void setAndroidConfig(AndroidOfflinePushInfo androidConfig) {
        this.androidConfig = androidConfig;
    }
}
